# Generated by roxygen2: do not edit by hand

S3method("[",pedmat)
S3method("[",tidyped)
S3method(as.matrix,pedmat)
S3method(as.vector,pedmat)
S3method(dim,pedmat)
S3method(length,pedmat)
S3method(plot,pedhalflife)
S3method(plot,pedstats)
S3method(plot,tidyped)
S3method(print,pedcontrib)
S3method(print,pedhalflife)
S3method(print,pediv)
S3method(print,pedmat)
S3method(print,pedstats)
S3method(print,splitped)
S3method(print,summary.pedmat)
S3method(print,summary.tidyped)
S3method(print,tidyped)
S3method(summary,pedmat)
S3method(summary,splitped)
S3method(summary,tidyped)
S3method(t,pedmat)
export(as_tidyped)
export(expand_pedmat)
export(has_candidates)
export(has_inbreeding)
export(inbreed)
export(is_tidyped)
export(pedancestry)
export(pedcontrib)
export(pedecg)
export(pedfclass)
export(pedgenint)
export(pedhalflife)
export(pediv)
export(pedmat)
export(pedmeta)
export(pedne)
export(pedpartial)
export(pedprod)
export(pedrel)
export(pedstats)
export(pedsubpop)
export(query_relationship)
export(splitped)
export(summary_pedmat)
export(tidyped)
export(vismat)
export(visped)
import(data.table)
import(igraph)
importFrom(Rcpp,sourceCpp)
importFrom(data.table,as.data.table)
importFrom(grDevices,colorRampPalette)
importFrom(grDevices,dev.cur)
importFrom(grDevices,dev.off)
importFrom(grDevices,pdf)
importFrom(grDevices,svg)
importFrom(graphics,strwidth)
importFrom(igraph,E)
importFrom(igraph,V)
importFrom(igraph,add_vertices)
importFrom(igraph,as_adj_list)
importFrom(igraph,components)
importFrom(igraph,degree)
importFrom(igraph,distances)
importFrom(igraph,edge_attr)
importFrom(igraph,ego)
importFrom(igraph,ends)
importFrom(igraph,graph_from_data_frame)
importFrom(igraph,graph_from_edgelist)
importFrom(igraph,is_dag)
importFrom(igraph,layout_with_sugiyama)
importFrom(igraph,neighborhood)
importFrom(igraph,neighbors)
importFrom(igraph,norm_coords)
importFrom(igraph,plot.igraph)
importFrom(igraph,shortest_paths)
importFrom(igraph,subcomponent)
importFrom(igraph,topo_sort)
importFrom(igraph,vcount)
importFrom(igraph,vertex_attr)
importFrom(igraph,which_loop)
importFrom(lattice,histogram)
importFrom(lattice,levelplot)
importFrom(lattice,panel.abline)
importFrom(lattice,panel.levelplot)
importFrom(stats,as.dist)
importFrom(stats,as.formula)
importFrom(stats,hclust)
importFrom(stats,median)
importFrom(stats,sd)
importFrom(stats,setNames)
importFrom(utils,head)
importFrom(utils,modifyList)
useDynLib(visPedigree, .registration = TRUE)
