#' @importFrom Rcpp sourceCpp
#' @importFrom stats as.formula sd
#' @useDynLib visPedigree, .registration = TRUE
if (getRversion() >= "2.15.1") {
  utils::globalVariables(
    c(
      ".",
      "..new_names",
      "..ped_column_name_new",
      "Cand",
      "Dam",
      "DamNum",
      "FamilyLabel",
      "Gen",
      "Ind",
      "IndNum",
      "MaxTraceGen",
      "N",
      "Sex",
      "Sire",
      "SireNum",
      "TraceDirec",
      "TraceGen",
      "TraceGenInd",
      "TraceGenInterval",
      "damlabel",
      "damnum",
      "f",
      "familylabel",
      "familynum",
      "from",
      "gen",
      "i.f_val",
      "i.minx",
      "id",
      "label",
      "layer",
      "nodetype",
      "sex",
      "sirelabel",
      "sirenum",
      "to",
      "tonodecolor",
      "x",
      "meanspace",
      "range",
      "familylabelsex",
      "familysize",
      "highlighted",
      "color",
      "frame.color",
      "label.color",
      "frame.width",
      "label.font",
      "to_highlighted",
      "from_highlighted",
      "compact_id",
      "compact_label",
      "from_id",
      "to_id",
      "to_label",
      "sib_offset",
      "fam_center",
      "final_center",
      "bwd_pos",
      "fwd_pos",
      "half_width",
      "target_x",
      "original_x_mean",
      "parent_mid",
      "dam_x",
      "sire_x",
      "px",
      "i.final_center",
      "i.px",
      "DamH",
      "Height",
      "MaxH",
      "SireH",
      "i.fam_center",
      "i.sib_offset",
      "i.x",
      "i.y",
      "size",
      "size2",
      "y",
      "..cols",
      "..new_names_edge",
      "..new_names_node",
      "family_key",
      "family_label",
      "family_size",
      "FamilySize",
      "FamilyID",
      "RepInd",
      "RepIndNum",
      "IsRepresentative",
      "IsCompacted",
      "IsParent",
      "SizeCategory",
      "i.Ind",
      "i.IndNum",
      "FamilyLabel",
      "OldIndNum",
      "OldRepIndNum",
      "NewNum",
      "OldNum",
      "NewSireNum",
      "NewDamNum",
      "NewRepIndNum",
      "NewIndNum",
      "OrigRepInd"
    )
  )
}

utils::globalVariables(c('i.SireNum', 'i.DamNum', 'i.Sire', 'i.Dam', 'i.IsParent', 'sort_key', 'NCompressed', 'Family', 'grp', 'NewGen', 'Limit', 'CohortLabel', 'DeltaF_Ind', 'ECG', 'monoecious_nums', 'role',
  '.orig_order_visped', 'Cohort', 'Contrib', 'Count', 'CumContrib', 'DeltaF', 'FClass', 'GenEquiv', 'Group', 'Interval', 'Mean', 'Ne', 'Pathway', 'Percentage', 'Rank', 'Time', 'child', 'child_label', 'family_id', 'from_label', 'i.label', 'rep_dam', 'rep_sire', 'Fe', 'Fa', 'Fg', 'LnFe', 'LnFa', 'LnFg', 'LnFaFe', 'LnFgFa', 'fe', 'fa', 'fg', 'lnfe', 'lnfa', 'lnfg', 'lnfafe', 'lnfgfa', 'TimeStep', 'Value', 'Metric'))
