% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-s3.R
\name{require_complete_pedigree}
\alias{require_complete_pedigree}
\title{Error on row-truncated pedigree subsets}
\usage{
require_complete_pedigree(ped, fun)
}
\arguments{
\item{ped}{A pedigree-like object.}

\item{fun}{Character scalar. Calling function name for the error message.}
}
\value{
The input object, invisibly.
}
\description{
Error on row-truncated pedigree subsets
}
\keyword{internal}
