% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/visped_style.R
\name{fade_cols}
\alias{fade_cols}
\title{Fade colors by appending a reduced alpha value}
\usage{
fade_cols(x)
}
\arguments{
\item{x}{Character vector of colors.}
}
\value{
Character vector of faded hex colors.
}
\description{
Converts any R color specification to `#RRGGBB4D` form.
Handles hex colors (`#RRGGBB`, `#RRGGBBAA`) and named colors (e.g. `"red"`).
}
\keyword{internal}
