% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/data.R
\docType{data}
\name{half_founder_ped}
\alias{half_founder_ped}
\title{A pedigree with half founders}
\format{
A data.frame with 4 columns:
\describe{
  \item{Ind}{Individual ID}
  \item{Sire}{Sire ID}
  \item{Dam}{Dam ID}
  \item{Sex}{Sex of the individual}
}
}
\usage{
half_founder_ped
}
\description{
A dataset from ENDOG containing individuals with a single missing parent (half founders).
Useful for testing genetic algorithms correctly conserving probability mass for missing lineages.
}
\keyword{datasets}
