% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/utils-s3.R
\name{ensure_tidyped}
\alias{ensure_tidyped}
\title{Internal helper to ensure ped is a tidyped object}
\usage{
ensure_tidyped(ped)
}
\arguments{
\item{ped}{An object expected to be a tidyped.}
}
\value{
A valid tidyped object.
}
\description{
If the object has lost its \code{tidyped} class (e.g., after \code{merge()},
\code{rbind()}, or dplyr operations) but still contains the required columns,
the class is automatically restored with an informational message. Otherwise,
an error is raised guiding the user to call \code{tidyped()} or
\code{as_tidyped()}.
}
\keyword{internal}
